
TODO: TODO_76_62_32_52: detect no args

Dilemma: if function expects N envelopes, there is no way to detect no args option because no args option lists all max N envelopes.
Maybe there should be a way to indicate it for client side (that the last envelope search had no criteria to search)?

NOTE: This can be detected by checking assigned `prop_name`-s - if none of them explicit, no `arg_value`-s were used.

Similar to TODO: TODO_20_61_16_31 `cardinality_hook`, this can be done on:
*   Client-side: (simpler for `argrelay`) let each delegator decide by itself
*   Server-side: (simpler for users) redirect to generic handler
